@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '2.039';
+our $VERSION = '2.040';
 
 #use bytes; # required
 use Scalar::Util qw( looks_like_number );
@@ -130,7 +130,7 @@ sub get_db_handle {
 sub get_schemas {
     my ( $sf, $dbh, $db ) = @_;
     my ( $user_schema, $sys_schema );
-    if ( $sf->{Plugin}->can( 'schemas' ) ) {
+    if ( $sf->{Plugin}->can( 'get_schemas' ) ) {
         ( $user_schema, $sys_schema ) = $sf->{Plugin}->get_schemas( $dbh, $db );
     }
     else {
@@ -172,11 +172,76 @@ sub get_schemas {
 }
 
 
-#sub primary_key_auto {
-#    my ( $sf ) = @_;
-#    return if ! $sf->{Plugin}->can( 'primary_key_auto' ); #
-#    return $sf->{Plugin}->primary_key_auto();
-#}
+sub first_column_is_autoincrement {
+    my ( $sf, $dbh, $schema, $table ) = @_;
+    if ( $sf->{Plugin}->can( 'first_column_is_autoincrement' ) ) {
+        return $sf->{Plugin}->first_column_is_autoincrement( $dbh, $schema, $table );
+    }
+    if ( $sf->get_db_driver eq 'SQLite' ) {
+        my $sql = "SELECT sql FROM sqlite_master WHERE name = ?";
+        my ( $row ) = $dbh->selectrow_array( $sql, {}, $table );
+        my $qt_table = $dbh->quote_identifier( $table );
+        my $sth = $dbh->prepare( "SELECT * FROM " . $qt_table . " LIMIT 0" );
+        my $col = $sth->{NAME}[0];
+        my $qt_col = $dbh->quote_identifier( $col );
+        if ( $row =~ /^\s*CREATE\s+TABLE\s+(?:\Q$table\E|\Q$qt_table\E)\s+\(\s*(?:\Q$col\E|\Q$qt_col\E)\s+INTEGER\s+PRIMARY\s+KEY[^,]*,/i ) {
+            return 1;
+        }
+    }
+    elsif ( $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/ ) {
+        my $sql = "SELECT COUNT(*) FROM information_schema.columns WHERE
+                TABLE_SCHEMA = ?
+                AND TABLE_NAME = ?
+                AND ORDINAL_POSITION = 1
+                AND DATA_TYPE = 'int'
+                AND COLUMN_DEFAULT IS NULL
+                AND IS_NULLABLE = 'NO'
+                AND EXTRA like '%auto_increment%'";
+        my ( $first_col_is_autoincrement ) = $dbh->selectrow_array( $sql, {}, $schema, $table );
+        return $first_col_is_autoincrement;
+    }
+    elsif ( $sf->get_db_driver eq 'Pg' ) {
+        my $sql = "SELECT COUNT(*) FROM information_schema.columns WHERE
+                TABLE_SCHEMA = ?
+                AND TABLE_NAME = ?
+                AND ORDINAL_POSITION = 1
+                AND DATA_TYPE = 'integer'
+                AND IS_NULLABLE = 'NO'
+                AND (
+                    UPPER(column_default) LIKE 'NEXTVAL%' OR
+                    UPPER(identity_generation) = 'BY DEFAULT'
+                )";
+        my ( $first_col_is_autoincrement ) = $dbh->selectrow_array( $sql, {}, $schema, $table );
+        return $first_col_is_autoincrement;
+    }
+    return;
+}
+
+
+sub primary_key_autoincrement_constraint {
+    # provide "primary_key_autoincrement_constraint" only if also "first_col_is_autoincrement" is available
+    my ( $sf, $dbh ) = @_;
+    if ( $sf->{Plugin}->can( 'primary_key_autoincrement_constraint' ) ) {
+        return $sf->{Plugin}->primary_key_autoincrement_constraint();
+    }
+    if ( $sf->get_db_driver eq 'SQLite' ) {
+        return "INTEGER PRIMARY KEY";
+    }
+    if ( $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/ ) {
+        return "INT NOT NULL AUTO_INCREMENT PRIMARY KEY";
+        # mysql: NOT NULL added automatically with AUTO_INCREMENT
+    }
+    if ( $sf->get_db_driver eq 'Pg' ) {
+        my ( $pg_version ) = $dbh->selectrow_array( "SELECT version()" );
+        if ( $pg_version =~ /^\S+\s+([0-9]+)(?:\.[0-9]+)*\s/ && $1 >= 10 ) {
+            # since PostgreSQL version 10
+            return "INT generated BY DEFAULT AS IDENTITY PRIMARY KEY";
+        }
+        else {
+            return "SERIAL PRIMARY KEY";
+        }
+    }
+}
 
 
 sub regexp {
@@ -238,7 +303,7 @@ sub concatenate {
     }
     return 'concat(' . join( ',', @$arg ) . ')'  if $sf->get_db_driver =~ /^(?:mysql|MariaDB)\z/;
 
-    return join( ' || ', @$arg ); # " || '$sep' || "
+    return join( ' || ', @$arg );
 }
 
 
@@ -315,7 +380,7 @@ App::DBBrowser::DB - Database plugin documentation.
 
 =head1 VERSION
 
-Version 2.039
+Version 2.040
 
 =head1 DESCRIPTION
 
@@ -505,6 +570,18 @@ Returns the user-schemas as an array-reference and the system-schemas as an arra
 
 If the option I<add_metadata> is true, user-schemas and system-schemas are used else only the user-schemas are used.
 
+=head4 first_column_is_autoincrement( $dbh, $schema, $table )
+
+Returns true or false. If the first column of C<$table> is an auto increment column, it returns true else it returns
+false.
+
+=head4 primary_key_autoincrement_constraint( $dbh );
+
+Provide C<primary_key_autoincrement_constraint> only if also C<first_col_is_autoincrement> is available.
+
+Returns the column constraint which is used for the first column of the table if I<Add auto increment column> is
+enabled. The constraint contains also the data type if a data type is required.
+
 =head4 regexp( $column_name, $do_not_match, $case_sensitive )
 
 C<$do_not_match> and C<$case_sensitive> are true or false.
